@@ -331,7 +331,7 @@ class Database(object):
         This method id broken. Use Document.delete() instead
         """
         data = self.resource.head(id)
-        self.resource.delete(id, rev=resp['etag'].strip('"'))
+        self.resource.delete(id, data=resp['etag'].strip('"'))
 
     def __getitem__(self, id):
         """Return the document with the specified ID.
